@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -142,7 +142,7 @@ op_helper (HTMLObject *self, HTMLEngine *e, GList *from, GList *to, GList *left,
 	o    = (from) ? HTML_OBJECT (from->data) : clue->head;
 	last = (to)   ? HTML_OBJECT (to->data)   : clue->tail;
 
-	if ((o == NULL) && (last == NULL))
+	if ((o == NULL) || (last == NULL))
 		return cc;
 
 	if (HTML_IS_TEXT_SLAVE (last))
@@ -221,9 +221,7 @@ static void
 split (HTMLObject *self, HTMLEngine *e, HTMLObject *child, gint offset, gint level, GList **left, GList **right)
 {
 	HTMLObject *dup;
-	HTMLClue *clue;
 
-	clue = HTML_CLUE (self);
 	dup  = html_object_dup (self);
 
 	HTML_CLUE (dup)->tail  = HTML_CLUE (self)->tail;
