@@ -349,8 +349,7 @@ set_max_height (HTMLObject *o, HTMLPainter *painter, gint height)
 {
 	HTMLClue *clue = HTML_CLUE (o);
 
-	/* Is it necessary to calc size here? It doesn't seem to. */
-	/* html_object_calc_size (o, painter, NULL); */
+	html_object_calc_size (o, painter, NULL);
 	if (o->ascent < height) {
 		(* HTML_OBJECT_CLASS (parent_class)->set_max_height) (o, painter, height);
 		clue->curr = NULL;
