@@ -17,8 +17,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _HTMLOBJECT_H_
@@ -263,7 +263,9 @@ struct _HTMLObjectClass {
 	HTMLDirection (*get_direction)   (HTMLObject *self);
 
 	gboolean (*cursor_forward)       (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
-	gboolean (*cursor_backward)       (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
+	gboolean (*cursor_forward_one)   (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
+	gboolean (*cursor_backward)      (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
+	gboolean (*cursor_backward_one)  (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
 	gboolean (*cursor_right)         (HTMLObject *self, HTMLPainter *painter, HTMLCursor *cursor);
 	gboolean (*cursor_left)          (HTMLObject *self, HTMLPainter *painter, HTMLCursor *cursor);
 
@@ -465,9 +467,15 @@ HTMLObject     *html_object_check_point           (HTMLObject            *clue,
 gboolean        html_object_cursor_forward        (HTMLObject            *self,
 						   HTMLCursor            *cursor,
 						   HTMLEngine            *engine);
+gboolean        html_object_cursor_forward_one    (HTMLObject            *self,
+						   HTMLCursor            *cursor,
+						   HTMLEngine            *engine);
 gboolean        html_object_cursor_backward       (HTMLObject            *self,
 						   HTMLCursor            *cursor,
 						   HTMLEngine            *engine);
+gboolean        html_object_cursor_backward_one   (HTMLObject            *self,
+						   HTMLCursor            *cursor,
+						   HTMLEngine            *engine);
 gboolean        html_object_cursor_left           (HTMLObject            *self,
 						   HTMLPainter           *painter,
 						   HTMLCursor            *cursor);
